==> zent-10.0.13-beta.0.tgz: package/es/placeholder/presets/RichTextBlock.js <==
import { __assign, __extends } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { PureComponent } from 'react';
import cx from 'classnames';
import Circle from '../shapes/Circle';
import Rectangle from '../shapes/Rectangle';
import TextBlock from './TextBlock';
var RichTextBlock = (function (_super) {
    __extends(RichTextBlock, _super);
    function RichTextBlock() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RichTextBlock.prototype.render = function () {
        var _a = this.props, className = _a.className, style = _a.style, rows = _a.rows, shape = _a.shape, size = _a.size, animate = _a.animate, dashed = _a.dashed, widths = _a.widths, dashSegments = _a.dashSegments, lineSpacing = _a.lineSpacing;
        var classes = cx('zent-placeholder-richtext-block', className);
        var shapeStyle = { marginRight: 10 };
        return (_jsxs("div", __assign({ className: classes, style: __assign(__assign({}, style), { display: 'flex' }), "data-zv": 'v10.0.13-beta.0' }, { children: [shape === 'circle' ? (_jsx(Circle, { style: shapeStyle, diameter: size, animate: animate }, void 0)) : (_jsx(Rectangle, { style: shapeStyle, width: size, height: size, animate: animate }, void 0)), _jsx(TextBlock, { rows: rows, animate: animate, dashed: dashed, widths: widths, dashSegments: dashSegments, lineSpacing: lineSpacing }, void 0)] }), void 0));
    };
    RichTextBlock.defaultProps = {
        style: {},
        className: '',
        shape: 'circle',
        animate: true,
        dashed: true,
        size: 80,
    };
    return RichTextBlock;
}(PureComponent));
export default RichTextBlock;

==> zent-10.0.17-beta.0.tgz: package/es/placeholder/presets/RichTextBlock.js <==
import { __assign, __extends } from "tslib";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { PureComponent } from 'react';
import cx from 'classnames';
import Circle from '../shapes/Circle';
import Rectangle from '../shapes/Rectangle';
import TextBlock from './TextBlock';
var RichTextBlock = (function (_super) {
    __extends(RichTextBlock, _super);
    function RichTextBlock() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    RichTextBlock.prototype.render = function () {
        var _a = this.props, className = _a.className, style = _a.style, rows = _a.rows, shape = _a.shape, size = _a.size, animate = _a.animate, dashed = _a.dashed, widths = _a.widths, dashSegments = _a.dashSegments, lineSpacing = _a.lineSpacing;
        var classes = cx('zent-placeholder-richtext-block', className);
        var shapeStyle = { marginRight: 10 };
        return (_jsxs("div", __assign({ className: classes, style: __assign(__assign({}, style), { display: 'flex' }), "data-zv": '10.0.11-beta.0' }, { children: [shape === 'circle' ? (_jsx(Circle, { style: shapeStyle, diameter: size, animate: animate }, void 0)) : (_jsx(Rectangle, { style: shapeStyle, width: size, height: size, animate: animate }, void 0)), _jsx(TextBlock, { rows: rows, animate: animate, dashed: dashed, widths: widths, dashSegments: dashSegments, lineSpacing: lineSpacing }, void 0)] }), void 0));
    };
    RichTextBlock.defaultProps = {
        style: {},
        className: '',
        shape: 'circle',
        animate: true,
        dashed: true,
        size: 80,
    };
    return RichTextBlock;
}(PureComponent));
export default RichTextBlock;
